(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common')) :
    typeof define === 'function' && define.amd ? define('ngx-pattern', ['exports', '@angular/core', '@angular/common'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global["ngx-pattern"] = {}, global.ng.core, global.ng.common));
})(this, (function (exports, i0, common) { 'use strict';

    function _interopNamespace(e) {
        if (e && e.__esModule) return e;
        var n = Object.create(null);
        if (e) {
            Object.keys(e).forEach(function (k) {
                if (k !== 'default') {
                    var d = Object.getOwnPropertyDescriptor(e, k);
                    Object.defineProperty(n, k, d.get ? d : {
                        enumerable: true,
                        get: function () { return e[k]; }
                    });
                }
            });
        }
        n["default"] = e;
        return Object.freeze(n);
    }

    var i0__namespace = /*#__PURE__*/_interopNamespace(i0);

    var NgxPatternDirective = /** @class */ (function () {
        function NgxPatternDirective(host, document) {
            this.host = host;
            this.document = document;
        }
        NgxPatternDirective.prototype.ngOnChanges = function (changes) {
            if (this.ngxPattern) {
                if (typeof this.ngxPattern === 'string') {
                    this.regExPattern = new RegExp("^" + this.ngxPattern + "$", 'g');
                }
                else {
                    this.regExPattern = this.ngxPattern;
                }
            }
        };
        NgxPatternDirective.prototype.onKeyDown = function (event) {
            if (this.regExPattern && noKeyFlags(event) && !isSpecialKey(event.key)) {
                if (!this.validWithChange(event.key)) {
                    event.preventDefault();
                }
            }
        };
        NgxPatternDirective.prototype.onInput = function () {
            if (!this.textIsValid(this.currentValue)) {
                // Mobile browsers don't support keydown preventDefault and return
                // Unidentified for the pressed key. We need to detect the change on input event and undo.
                this.document.execCommand('undo');
            }
        };
        NgxPatternDirective.prototype.onPaste = function (event) {
            if (event.clipboardData) {
                var pastedInput = event.clipboardData.getData('text/plain');
                if (!this.validWithChange(pastedInput)) {
                    event.preventDefault();
                }
            }
        };
        NgxPatternDirective.prototype.onDrop = function (event) {
            if (event.dataTransfer) {
                var textData = event.dataTransfer.getData('text');
                if (!this.validWithChange(textData)) {
                    event.preventDefault();
                }
            }
        };
        Object.defineProperty(NgxPatternDirective.prototype, "currentValue", {
            get: function () {
                return this.inputEl ? this.inputEl.value : undefined;
            },
            enumerable: false,
            configurable: true
        });
        NgxPatternDirective.prototype.validWithChange = function (delta) {
            var current = this.inputEl.value;
            var selectionStart = this.inputEl.selectionStart || 0;
            var selectionEnd = this.inputEl.selectionEnd || 0;
            var updated = current.substring(0, selectionStart) + delta + current.substring(selectionEnd + 1);
            return this.textIsValid(updated);
        };
        NgxPatternDirective.prototype.textIsValid = function (text) {
            if (this.regExPattern) {
                var result = !text || this.regExPattern.test(text);
                this.regExPattern.lastIndex = 0;
                return result;
            }
            return true;
        };
        Object.defineProperty(NgxPatternDirective.prototype, "inputEl", {
            get: function () {
                return this.host.nativeElement;
            },
            enumerable: false,
            configurable: true
        });
        return NgxPatternDirective;
    }());
    NgxPatternDirective.ɵfac = i0__namespace.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0__namespace, type: NgxPatternDirective, deps: [{ token: i0.ElementRef }, { token: common.DOCUMENT }], target: i0__namespace.ɵɵFactoryTarget.Directive });
    NgxPatternDirective.ɵdir = i0__namespace.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.16", type: NgxPatternDirective, selector: "[ngxPattern]", inputs: { ngxPattern: "ngxPattern" }, host: { listeners: { "keydown": "onKeyDown($event)", "input": "onInput()", "paste": "onPaste($event)", "drop": "onDrop($event)" } }, usesOnChanges: true, ngImport: i0__namespace });
    i0__namespace.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0__namespace, type: NgxPatternDirective, decorators: [{
                type: i0.Directive,
                args: [{
                        selector: '[ngxPattern]'
                    }]
            }], ctorParameters: function () {
            return [{ type: i0__namespace.ElementRef, decorators: [{
                            type: i0.Inject,
                            args: [i0.ElementRef]
                        }] }, { type: undefined, decorators: [{
                            type: i0.Inject,
                            args: [common.DOCUMENT]
                        }] }];
        }, propDecorators: { ngxPattern: [{
                    type: i0.Input
                }], onKeyDown: [{
                    type: i0.HostListener,
                    args: ['keydown', ['$event']]
                }], onInput: [{
                    type: i0.HostListener,
                    args: ['input', []]
                }], onPaste: [{
                    type: i0.HostListener,
                    args: ['paste', ['$event']]
                }], onDrop: [{
                    type: i0.HostListener,
                    args: ['drop', ['$event']]
                }] } });
    function noKeyFlags(event) {
        return !event.ctrlKey && !event.altKey && !event.metaKey;
    }
    /** @see https://developer.mozilla.org/bg/docs/Web/API/KeyboardEvent/key/Key_Values */
    function isSpecialKey(key) {
        return key.length > 1;
    }

    var NgxPatternModule = /** @class */ (function () {
        function NgxPatternModule() {
        }
        return NgxPatternModule;
    }());
    NgxPatternModule.ɵfac = i0__namespace.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0__namespace, type: NgxPatternModule, deps: [], target: i0__namespace.ɵɵFactoryTarget.NgModule });
    NgxPatternModule.ɵmod = i0__namespace.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0__namespace, type: NgxPatternModule, declarations: [NgxPatternDirective], exports: [NgxPatternDirective] });
    NgxPatternModule.ɵinj = i0__namespace.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0__namespace, type: NgxPatternModule, imports: [[]] });
    i0__namespace.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0__namespace, type: NgxPatternModule, decorators: [{
                type: i0.NgModule,
                args: [{
                        declarations: [NgxPatternDirective],
                        imports: [],
                        exports: [
                            NgxPatternDirective
                        ]
                    }]
            }] });

    /*
     * Public API Surface of ngx-pattern
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.NgxPatternDirective = NgxPatternDirective;
    exports.NgxPatternModule = NgxPatternModule;

    Object.defineProperty(exports, '__esModule', { value: true });

}));
//# sourceMappingURL=ngx-pattern.umd.js.map
