import * as i0 from '@angular/core';
import { ElementRef, Directive, Inject, Input, HostListener, NgModule } from '@angular/core';
import { DOCUMENT } from '@angular/common';

class NgxPatternDirective {
    constructor(host, document) {
        this.host = host;
        this.document = document;
    }
    ngOnChanges(changes) {
        if (this.ngxPattern) {
            if (typeof this.ngxPattern === 'string') {
                this.regExPattern = new RegExp(`^${this.ngxPattern}$`, 'g');
            }
            else {
                this.regExPattern = this.ngxPattern;
            }
        }
    }
    onKeyDown(event) {
        if (this.regExPattern && noKeyFlags(event) && !isSpecialKey(event.key)) {
            if (!this.validWithChange(event.key)) {
                event.preventDefault();
            }
        }
    }
    onInput() {
        if (!this.textIsValid(this.currentValue)) {
            // Mobile browsers don't support keydown preventDefault and return
            // Unidentified for the pressed key. We need to detect the change on input event and undo.
            this.document.execCommand('undo');
        }
    }
    onPaste(event) {
        if (event.clipboardData) {
            const pastedInput = event.clipboardData.getData('text/plain');
            if (!this.validWithChange(pastedInput)) {
                event.preventDefault();
            }
        }
    }
    onDrop(event) {
        if (event.dataTransfer) {
            const textData = event.dataTransfer.getData('text');
            if (!this.validWithChange(textData)) {
                event.preventDefault();
            }
        }
    }
    get currentValue() {
        return this.inputEl ? this.inputEl.value : undefined;
    }
    validWithChange(delta) {
        const current = this.inputEl.value;
        const selectionStart = this.inputEl.selectionStart || 0;
        const selectionEnd = this.inputEl.selectionEnd || 0;
        const updated = current.substring(0, selectionStart) + delta + current.substring(selectionEnd + 1);
        return this.textIsValid(updated);
    }
    textIsValid(text) {
        if (this.regExPattern) {
            const result = !text || this.regExPattern.test(text);
            this.regExPattern.lastIndex = 0;
            return result;
        }
        return true;
    }
    get inputEl() {
        return this.host.nativeElement;
    }
}
NgxPatternDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: NgxPatternDirective, deps: [{ token: ElementRef }, { token: DOCUMENT }], target: i0.ɵɵFactoryTarget.Directive });
NgxPatternDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.16", type: NgxPatternDirective, selector: "[ngxPattern]", inputs: { ngxPattern: "ngxPattern" }, host: { listeners: { "keydown": "onKeyDown($event)", "input": "onInput()", "paste": "onPaste($event)", "drop": "onDrop($event)" } }, usesOnChanges: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: NgxPatternDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngxPattern]'
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef, decorators: [{
                    type: Inject,
                    args: [ElementRef]
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }]; }, propDecorators: { ngxPattern: [{
                type: Input
            }], onKeyDown: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }], onInput: [{
                type: HostListener,
                args: ['input', []]
            }], onPaste: [{
                type: HostListener,
                args: ['paste', ['$event']]
            }], onDrop: [{
                type: HostListener,
                args: ['drop', ['$event']]
            }] } });
function noKeyFlags(event) {
    return !event.ctrlKey && !event.altKey && !event.metaKey;
}
/** @see https://developer.mozilla.org/bg/docs/Web/API/KeyboardEvent/key/Key_Values */
function isSpecialKey(key) {
    return key.length > 1;
}

class NgxPatternModule {
}
NgxPatternModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: NgxPatternModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxPatternModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: NgxPatternModule, declarations: [NgxPatternDirective], exports: [NgxPatternDirective] });
NgxPatternModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: NgxPatternModule, imports: [[]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: NgxPatternModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [NgxPatternDirective],
                    imports: [],
                    exports: [
                        NgxPatternDirective
                    ]
                }]
        }] });

/*
 * Public API Surface of ngx-pattern
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxPatternDirective, NgxPatternModule };
//# sourceMappingURL=ngx-pattern.js.map
